# README

![Python](https://img.shields.io/badge/python-3.11-blue.svg)
[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/ireiat/badge/?version=latest)](https://ireiat.readthedocs.io/en/latest/?badge=latest)

# Purpose

The Intermodal Routing and Environmental Impact Analysis Tool (IREIAT) is meant to enable its target user group,
infrastructure planners, to understand:
1. Expected flows on the US intermodal freight network given demand,
   intermodal costs (both direct financial and other costs), and network capacities
2. How cost, transit time, disruptions/resilience, and GHG emissions affect freight flows across the current and
   future intermodal network

# Quick start

The tool is meant to be a Python-based command line tool, so you should ensure
that you have Python 3.11 installed on your machine, which
can be downloaded [here](https://www.python.org/downloads/release/python-3117/).

Additionally, you need to download R and install:
* cppRouting
* igraph
* arrow

Once you have Python and R installed you should be able to install the package
with `pip install ireiat`. After which, you can just run `ireiat` from a command-line!

Run `ireiat --help` for CLI options or see the [full documentation](https://ireiat.readthedocs.io/en/latest/).

# Contributing

Please see [how to contribute](CONTRIBUTING.md)

# Acknowledgement

The information, data, or work presented herein was funded in part by the Advanced Research Projects Agency-Energy
(ARPA-E), U.S. Department of Energy, under Award Number DE-AR0001784. The views and opinions of authors expressed herein do not necessarily state or reflect those of the United States Government or any agency thereof.
